@@ -1,4 +1,4 @@
-#!/usr/bin/env python3
+#!/usr/bin/env python
 
 from collections import Counter
 from Levenshtein import hamming
@@ -7,8 +7,8 @@ import pandas as pd
 import sqlite3
 import random
 
-from .parser import parse_fasta
-from .preprocessor import Preprocessor
+from parser import parse_fasta
+from preprocessor import Preprocessor
 
 
 splits = []
@@ -114,6 +114,9 @@ class Matcher(Preprocessor):
     all_matches_dict = {}
 
     for peptide in peptides:
+      if len(peptide) < self.split:
+        continue
+
       all_matches_dict[peptide] = []
       kmers = self.split_peptide(peptide, self.split)
 
@@ -124,12 +127,15 @@ class Matcher(Preprocessor):
       hit_list = []
       if len(peptide) % self.split == 0:
         for i in range(0, len(kmers), self.split):
+          
           get_positions = 'SELECT position FROM "{kmer_table}" WHERE kmer = "{actual_kmer}"'.format(kmer_table = kmers_table_name, actual_kmer = kmers[i])
           c.execute(get_positions)
           positions_fetch = c.fetchall()
+          
           try:
             for hit in positions_fetch:
               hit_list.append(hit[0] - i)
+          
           except:
             continue
 
@@ -192,10 +198,11 @@ class Matcher(Preprocessor):
         all_matches.append((peptide, 
                             peptide, 
                             protein_data[0][1],
+                            protein_data[0][2],
                             (match % 100000),
                             (match % 100000) + len(peptide), 
-                            protein_data[0][2], 
-                            protein_data[0][3]))
+                            protein_data[0][3], 
+                            protein_data[0][4]))
 
     c.close()
     conn.close()
@@ -385,6 +392,7 @@ class Matcher(Preprocessor):
             peptide,
             match[0],
             names_dict[(match[2] - (match[2] % 100000)) // 100000][0],
+            names_dict[(match[2] - (match[2] % 100000)) // 100000][1],
             match[1],
             [i+1 for i in range(len(peptide)) if peptide[i] != match[0][i]],
             match[2] % 100000,
@@ -497,6 +505,7 @@ class Matcher(Preprocessor):
                       columns=['Peptide Sequence',
                                'Matched Peptide',
                                'Protein ID',
+                               'Protein Name',
                                'Index start',
                                'Index end',
                                'Protein Evidence Level',
